<?php

namespace Drupal\simple_sitemap_language_hierarchy;

use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Class LanguageHierarchyManager.
 *
 * @package Drupal\simple_sitemap_language_hierarchy
 */
class LanguageHierarchyManager {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Contruct.
   */
  public function __construct(EntityTypeManagerInterface $entity_manager) {
    $this->entityTypeManager = $entity_manager;
  }

  /**
   * Get all language parent.
   */
  public function getAllParentLanguage($langCode, $languageConfigEntities = FALSE) {

    // Check lang code.
    if (empty($langCode)) {
      return FALSE;
    }

    $result = &drupal_static(__FUNCTION__);

    if (!empty($result[$langCode])) {
      return $result[$langCode];
    }

    // Initial value.
    $result[$langCode] = [];

    // Get fallback language.
    $languageFallback = $this->getLanguageFallback($langCode, $languageConfigEntities);

    if (empty($languageFallback)) {
      return $result[$langCode];
    }

    $result[$langCode][] = $languageFallback;

    $currentlangCode = $languageFallback;

    while (!empty($languageFallback)) {

      $languageFallback = $this->getLanguageFallback($currentlangCode, $languageConfigEntities);

      if (empty($languageFallback)) {
        return $result[$langCode];
      }

      $result[$langCode][] = $languageFallback;

      $currentlangCode = $languageFallback;
    }

    return $result[$langCode];
  }

  /**
   * Get Languages Fallback.
   */
  public function getLanguageFallback($langCode, $languageConfigEntities = FALSE) {

    if (empty($langCode)) {
      return FALSE;
    }

    $langCodeFallbackParents = &drupal_static(__FUNCTION__);

    if (!empty($langCodeFallbackParents[$langCode])) {
      return $langCodeFallbackParents[$langCode];
    }

    $configManager = $this->entityTypeManager->getStorage('configurable_language');

    // If we already load this language config entity, use it. Else load a new.
    if (!empty($languageConfigEntities[$langCode])) {
      $languageConfigEntity = $languageConfigEntities[$langCode];
    }
    else {
      $languageConfigEntity = $configManager->load($langCode);
    }

    $langCodeFallbackParents[$langCode] = FALSE;
    if (!empty($languageConfigEntity->getThirdPartySetting('language_hierarchy', 'fallback_langcode', ''))) {
      $langCodeFallbackParents[$langCode] = $languageConfigEntity->getThirdPartySetting('language_hierarchy', 'fallback_langcode', '');
    }

    return $langCodeFallbackParents[$langCode];
  }

}
