<?php

namespace Drupal\simple_sitemap_language_hierarchy\Plugin\simple_sitemap\UrlGenerator;

use Drupal\simple_sitemap\Plugin\simple_sitemap\UrlGenerator\EntityUrlGenerator;
use Drupal\Core\Url;

/**
 * Class LanguageHierarchyUrlGenerator.
 *
 * @package Drupal\simple_sitemap_language_hierarchy\Plugin\simple_sitemap\UrlGenerator
 *
 * @UrlGenerator(
 *   id = "language_hierarchy_url_generator",
 *   label = @Translation("Entity URL generator"),
 *   description = @Translation("Generates URLs for entity bundles and bundle overrides."),
 * )
 */
class LanguageHierarchyUrlGenerator extends EntityUrlGenerator {

  /**
   * Generate alternate url for all possible languages.
   *
   * @param Drupal\Core\Url $url_object
   *   Url object used to genearate variations.
   */
  protected function getAlternateUrlsForAllLanguages(Url $url_object) {
    $alternate_urls = [];

    foreach ($this->languages as $language) {

      if (!isset($this->settings['excluded_languages'][$language->getId()]) || $language->isDefault()) {
        $alternate_urls[$language->getId()] = $this->replaceBaseUrlWithCustom($url_object
          ->setOption('language', $language)->toString(), $url_object
        );
      }
    }

    return $alternate_urls;

  }

}
